pub struct Serve<M, S> { /* private fields */ }Expand description
Future returned by serve.
Implementations
Sourceimpl<M, S> Serve<M, S>
impl<M, S> Serve<M, S>
Sourcepub fn with_graceful_shutdown<F>(
self,
signal: F,
) -> WithGracefulShutdown<M, S, F>
pub fn with_graceful_shutdown<F>( self, signal: F, ) -> WithGracefulShutdown<M, S, F>
Prepares a server to handle graceful shutdown when the provided future completes.
Example
use axum::{Router, routing::get};
let router = Router::new().route("/", get(|| async { "Hello, World!" }));
let listener = tokio::net::TcpListener::bind("0.0.0.0:3000").await.unwrap();
axum::serve(listener, router)
.with_graceful_shutdown(shutdown_signal())
.await
.unwrap();
async fn shutdown_signal() {
// ...
}Sourcepub fn tcp_nodelay(self, nodelay: bool) -> Serve<M, S>
pub fn tcp_nodelay(self, nodelay: bool) -> Serve<M, S>
Instructs the server to set the value of the TCP_NODELAY option on every accepted connection.
See also TcpStream::set_nodelay.
Example
use axum::{Router, routing::get};
let router = Router::new().route("/", get(|| async { "Hello, World!" }));
let listener = tokio::net::TcpListener::bind("0.0.0.0:3000").await.unwrap();
axum::serve(listener, router)
.tcp_nodelay(true)
.await
.unwrap();Sourcepub fn local_addr(&self) -> Result<SocketAddr, Error>
pub fn local_addr(&self) -> Result<SocketAddr, Error>
Returns the local address this server is bound to.